@@ -1,5 +1,6 @@
 from .keys import SIGN_PUB_KEY, SIGN_PRV_KEY
-from utils.qtum_utils.qtum import Qtum
+
+from qtum_utils.qtum import Qtum
 
 
 def verify(func):
